@@ -35,6 +35,7 @@ __all__ = (
     "ContainerPropertiesTypeDef",
     "ContainerSummaryTypeDef",
     "DeviceTypeDef",
+    "EvaluateOnExitTypeDef",
     "HostTypeDef",
     "JobDefinitionTypeDef",
     "JobDependencyTypeDef",
@@ -260,6 +261,20 @@ class DeviceTypeDef(_RequiredDeviceTypeDef, _OptionalDeviceTypeDef):
     pass
 
 
+_RequiredEvaluateOnExitTypeDef = TypedDict(
+    "_RequiredEvaluateOnExitTypeDef", {"action": Literal["RETRY", "EXIT"]}
+)
+_OptionalEvaluateOnExitTypeDef = TypedDict(
+    "_OptionalEvaluateOnExitTypeDef",
+    {"onStatusReason": str, "onReason": str, "onExitCode": str},
+    total=False,
+)
+
+
+class EvaluateOnExitTypeDef(_RequiredEvaluateOnExitTypeDef, _OptionalEvaluateOnExitTypeDef):
+    pass
+
+
 HostTypeDef = TypedDict("HostTypeDef", {"sourcePath": str}, total=False)
 
 _RequiredJobDefinitionTypeDef = TypedDict(
@@ -478,7 +493,11 @@ ResourceRequirementTypeDef = TypedDict(
     "ResourceRequirementTypeDef", {"value": str, "type": Literal["GPU"]}
 )
 
-RetryStrategyTypeDef = TypedDict("RetryStrategyTypeDef", {"attempts": int}, total=False)
+RetryStrategyTypeDef = TypedDict(
+    "RetryStrategyTypeDef",
+    {"attempts": int, "evaluateOnExit": List["EvaluateOnExitTypeDef"]},
+    total=False,
+)
 
 SecretTypeDef = TypedDict("SecretTypeDef", {"name": str, "valueFrom": str})
 
